@@ -232,7 +232,7 @@ class OperationClient:
         # even we delete it from the nvmf_conf["host"]
         if nvmf_conf is not None \
            and len(nvmf_conf["hosts"]) > 0 \
-           and nvmf_conf["hosts"][0]["name"] != frontend_nqn_name:
+           and nvmf_conf["hosts"][0]["nqn"] != frontend_nqn_name:
             params = {
                 "nqn": backend_nqn_name,
             }
@@ -260,7 +260,7 @@ class OperationClient:
                     traddr=dn_listener_conf["traddr"],
                     trsvcid=dn_listener_conf["trsvcid"],
                 )
-            if len(nvmf_conf["host"]) == 0:
+            if len(nvmf_conf["hosts"]) == 0:
                 self._create_nvmf_host(backend_nqn_name, frontend_nqn_name)
 
     def delete_backend_nvmf(self, backend_nqn_name):
@@ -431,7 +431,7 @@ class OperationClient:
 
     def create_exp_primary_nvmf(
             self,  exp_nqn_name, snap_full_name,
-            initiator_nqn, standby_nqn_list, cn_listener_conf):
+            initiator_nqn, secondary_nqn_list, cn_listener_conf):
         nvmf_conf = self.nvmf_dict.get(exp_nqn_name)
         if nvmf_conf is None:
             self._create_nvmf_subsystem(exp_nqn_name)
@@ -444,10 +444,10 @@ class OperationClient:
                 trsvcid=cn_listener_conf["trsvcid"],
             )
             self._create_nvmf_host(exp_nqn_name, initiator_nqn)
-            for standby_nqn in standby_nqn_list:
-                self._create_nvmf_host(exp_nqn_name, standby_nqn)
+            for secondary_nqn in secondary_nqn_list:
+                self._create_nvmf_host(exp_nqn_name, secondary_nqn)
         else:
-            if len(nvmf_conf["namespaces"] == 0):
+            if len(nvmf_conf["namespaces"]) == 0:
                 self._create_nvmf_ns(exp_nqn_name, snap_full_name)
             if len(nvmf_conf["listen_addresses"]) == 0:
                 self._create_nvmf_listener(
@@ -463,8 +463,8 @@ class OperationClient:
                 host_nqn_set_1.add(host_nqn)
             host_nqn_set_2 = set()
             host_nqn_set_2.add(initiator_nqn)
-            for standby_nqn in standby_nqn_list:
-                host_nqn_set_2.add(standby_nqn)
+            for secondary_nqn in secondary_nqn_list:
+                host_nqn_set_2.add(secondary_nqn)
             for host_nqn in host_nqn_set_1:
                 if host_nqn not in host_nqn_set_2:
                     self._delete_nvmf_host(exp_nqn_name, host_nqn)
@@ -472,13 +472,13 @@ class OperationClient:
                 if host_nqn not in host_nqn_set_1:
                     self._create_nvmf_host(exp_nqn_name, host_nqn)
 
-    def create_exp_standby_nvmf(
-            self, exp_nqn_name, standby_bdev_name,
+    def create_exp_secondary_nvmf(
+            self, exp_nqn_name, secondary_bdev_name,
             initiator_nqn, cn_listener_conf):
         nvmf_conf = self.nvmf_dict.get(exp_nqn_name)
         if nvmf_conf is not None \
            and len(nvmf_conf["namespaces"]) > 0 \
-           and nvmf_conf["namespaces"][0]["name"] != standby_bdev_name:
+           and nvmf_conf["namespaces"][0]["name"] != secondary_bdev_name:
             params = {
                 "nqn": exp_nqn_name,
             }
@@ -489,7 +489,7 @@ class OperationClient:
                 "nqn": exp_nqn_name,
             }
             self._create_nvmf_subsystem(exp_nqn_name)
-            self._create_nvmf_ns(exp_nqn_name, standby_bdev_name)
+            self._create_nvmf_ns(exp_nqn_name, secondary_bdev_name)
             self._create_nvmf_listener(
                 nqn=exp_nqn_name,
                 trtype=cn_listener_conf["trtype"],
@@ -532,43 +532,43 @@ class OperationClient:
                 exp_nqn_list.append(nqn)
         return exp_nqn_list
 
-    def create_standby_nvme(
-            self, standby_nvme_name, exp_nqn_name,
-            standby_nqn_name, primary_listener_conf_str):
+    def create_secondary_nvme(
+            self, secondary_nvme_name, exp_nqn_name,
+            secondary_nqn_name, primary_listener_conf_str):
         primary_listener_conf = json.loads(primary_listener_conf_str)
 
         params = {
-            "name": standby_nvme_name,
+            "name": secondary_nvme_name,
         }
         ret = self.spdk_client.call("bdev_nvme_get_controllers", params)
         if "result" in ret:
             return
 
         params = {
-            "name": standby_nvme_name,
+            "name": secondary_nvme_name,
             "trtype": primary_listener_conf["trtype"],
             "traddr": primary_listener_conf["traddr"],
             "adrfam": primary_listener_conf["adrfam"],
             "trsvcid": primary_listener_conf["trsvcid"],
             "subnqn": exp_nqn_name,
-            "hostnqn": standby_nqn_name,
+            "hostnqn": secondary_nqn_name,
         }
         self.spdk_client.call_and_check("bdev_nvme_attach_controller", params)
 
-    def delete_standby_nvme(self, standby_nvme_name):
+    def delete_secondary_nvme(self, secondary_nvme_name):
         params = {
-            "name": standby_nvme_name,
+            "name": secondary_nvme_name,
         }
         self.spdk_client.call("bdev_nvme_detach_controller", params)
 
-    def get_standby_nvme_list(self, standby_nvme_prefix):
+    def get_secondary_nvme_list(self, secondary_nvme_prefix):
         ret = self.spdk_client.call_and_check("bdev_nvme_get_controllers")
-        standby_nvme_list = []
+        secondary_nvme_list = []
         for nvme_conf in ret["result"]:
             name = nvme_conf["name"]
-            if name.startswith(standby_nvme_prefix):
-                standby_nvme_list.append(name)
-        return standby_nvme_list
+            if name.startswith(secondary_nvme_prefix):
+                secondary_nvme_list.append(name)
+        return secondary_nvme_list
 
     def create_main_snap(self, da_lvs_name, main_snap_name, da_size):
         params = {
