@@ -75,25 +75,30 @@ def do_dn_syncup(dn_cfg, spdk_client, local_store, dn_listener_conf):
             )
             backend_lvol_set.add(backend_lvol_fullname)
             backend_nqn_name = NameFmt.backend_nqn_name(vd_cfg.vd_id)
+            backend_nqn_set.add(backend_nqn_name)
             frontend_nqn_name = NameFmt.frontend_nqn_name(vd_cfg.cntlr_id)
-            try:
-                oc.create_backend_lvol(
-                    pd_lvs_name=pd_lvs_name,
-                    backend_lvol_name=backend_lvol_name,
-                    vd_clusters=vd_cfg.vd_clusters,
-                )
-                oc.create_backend_nvmf(
-                    backend_nqn_name=backend_nqn_name,
-                    backend_lvol_fullname=backend_lvol_fullname,
-                    frontend_nqn_name=frontend_nqn_name,
-                    dn_listener_conf=dn_listener_conf,
-                )
-            except SpdkError as e:
+            if pd_error:
                 vd_error = True
-                vd_error_msg = e.message
+                vd_error_msg = "stop"
             else:
-                vd_error = False
-                vd_error_msg = None
+                try:
+                    oc.create_backend_lvol(
+                        pd_lvs_name=pd_lvs_name,
+                        backend_lvol_name=backend_lvol_name,
+                        vd_clusters=vd_cfg.vd_clusters,
+                    )
+                    oc.create_backend_nvmf(
+                        backend_nqn_name=backend_nqn_name,
+                        backend_lvol_fullname=backend_lvol_fullname,
+                        frontend_nqn_name=frontend_nqn_name,
+                        dn_listener_conf=dn_listener_conf,
+                    )
+                except SpdkError as e:
+                    vd_error = True
+                    vd_error_msg = e.message
+                else:
+                    vd_error = False
+                    vd_error_msg = None
             vd_info = dn_agent_pb2.VdBackendInfo(
                 vd_id=vd_cfg.vd_id,
                 error=vd_error,
